from django.conf import settings
from django.db import models

class Page(models.Model):
	title = models.CharField(maxlength=255, verbose_name=_('Title'))
	slug = models.SlugField(maxlength=255, unique=True, prepopulate_from=("title", ), verbose_name=_('Slug'))
	description = models.CharField(maxlength=255, verbose_name=_('Description'))
	text = models.TextField(verbose_name=_('Text'))
	date = models.DateTimeField(auto_now_add = True)
	is_category = models.BooleanField(blank=True, default=False, verbose_name=_('Is Category'))
	wykop_field = models.CharField(maxlength=255, verbose_name='Wykop', blank=True)
	infoneo_field = models.CharField(maxlength=255, verbose_name='Infoneo', blank=True)
	jakilinux_field = models.CharField(maxlength=255, verbose_name='Jakilinux', blank=True)
	digg_field = models.CharField(maxlength=255, verbose_name='Digg', blank=True)
	reddit_field = models.CharField(maxlength=255, verbose_name='Reddit', blank=True)
	parent = models.ForeignKey('self', blank=True, null=True)
	class Meta:
		verbose_name = _('Page')
		verbose_name_plural = _('Pages')
		db_table = 'rk_page' + str(settings.SITE_ID)
	class Admin:
		list_display = ('title', 'slug', 'description')
		list_filter = ['date']
		search_fields = ['title', 'slug', 'text']
	def get_absolute_url(self):
		return '/w/p/' + self.slug + '/'
	def __str__(self):
		return self.title
